@@ -78,7 +78,7 @@ CREATE TABLE docfields (
   field_name char(80) NOT NULL default '',
   field_position int(4) NOT NULL default '0',
   field_type char(80) NOT NULL default '',
-  field_values text NOT NULL default '',
+  field_values text NOT NULL,
   field_size bigint(20) NOT NULL default '0',
   searchable int(4) NOT NULL default '0',
   show_desc int(4) NOT NULL DEFAULT 0 ,
@@ -115,7 +115,7 @@ CREATE TABLE docfieldvalues (
   id int(4) NOT NULL auto_increment,
   file_id int(4) NOT NULL default '0',
   field_name char(80) NOT NULL default '',
-  field_value text NOT NULL default '',
+  field_value text NOT NULL,
   PRIMARY KEY  (id)
 );
 
