@@ -215,7 +215,7 @@ CREATE TABLE ACTIVE_SESSIONS
   USID      VARCHAR2(25),
   LASTUSED  NUMBER(10),
   IP        VARCHAR2(16),
-  CURRENT_DB NUMBER(4)
+  CURRENTDB NUMBER(4)
 )
 PCTUSED    40
 PCTFREE    10
@@ -334,7 +334,8 @@ NOPARALLEL;
 CREATE TABLE MEMBERGROUP
 (
   USERID   NUMBER(4)                            NOT NULL,
-  GROUPID  NUMBER(4)                            NOT NULL
+  GROUPID  NUMBER(4) DEFAULT NULL,
+  GROUPADMIN NUMBER(4)                  
 )
 LOGGING 
 NOCACHE
@@ -420,7 +421,7 @@ CREATE TABLE PREFS
   EMAIL_FROM            VARCHAR2(80),
   EMAIL_FROMNAME        VARCHAR2(80),
   EMAIL_REPLYTO         VARCHAR2(80),
-  EMAIL_SERVER          VARCHAR2(30),
+  EMAIL_SERVER          VARCHAR2(80),
   EMAIL_SUBJECT         VARCHAR2(60),
   LOOKATHD              VARCHAR2(15),
   LOOKATHDDEL           NUMBER(4),
@@ -468,6 +469,7 @@ CREATE TABLE PREFS
   COLLECT_TRASH         NUMBER(4),
   TRASH_CAN_LOCATION    VARCHAR2(80),
   ALLOW_POPUP           NUMBER(4),
+  ALLOW_CUSTPOPUP       NUMBER(4),
   STATUS_BAR_LOCATION   NUMBER(4),
   --- HIDE_BULK             NUMBER(4),
   REMEMBER_ME           NUMBER(4),
@@ -512,7 +514,7 @@ CREATE TABLE PREFS
   expand_search_disp_modified 	NUMBER(4),
   expand_search_disp_action 	NUMBER(4),
   collapse_search_disp_score 	NUMBER(4),
-  collapse_search_disp_folder_pa 	NUMBER(4),
+  colps_search_disp_fld_path 	NUMBER(4),
   collapse_search_disp_doc_type 	NUMBER(4),
   collapse_search_disp_file 	NUMBER(4),
   collapse_search_disp_size 	NUMBER(4),
@@ -1064,6 +1066,7 @@ INSERT INTO mimes VALUES ('sxm','application/vnd.sun.xml.math');
        field_values VARCHAR2(80) not null,
        field_size number(38) not null,
        searchable number(4) not null,
+       show_desc number(4) default 0 not null,
        required number(4) not null,
          primary key (id)
      )
