@@ -9,7 +9,7 @@ CREATE TABLE active_sessions (
 
 CREATE TABLE membergroup (
         userid integer not null,
-        groupid integer not null,
+        groupid integer default null,
         groupadmin integer default NULL
 
 );
@@ -140,175 +140,176 @@ INSERT INTO html VALUES (1,'90%','50%','','owl_logo1.gif','#000000','#000000','#
 
 
 CREATE TABLE prefs (
-  id serial NOT NULL,
-  email_from character varying(80) default NULL,
-  email_fromname character varying(80) default NULL,
-  email_replyto character varying(80) default NULL,
-  email_server character varying(30) default NULL,
-  email_subject character varying(60) default NULL,
-  lookathd character varying(15) default NULL,
-  lookathddel integer default NULL,
-  def_file_security integer default NULL,
-  def_file_group_owner integer default NULL,
-  def_file_owner integer default NULL,
-  def_file_title character varying(40) default NULL,
-  def_file_meta character varying(40) default NULL,
-  def_fold_security integer default NULL,
-  def_fold_group_owner integer default NULL,
-  def_fold_owner integer default NULL,
-  max_filesize integer default NULL,
-  tmpdir character varying(255) default NULL,
-  timeout integer default NULL,
-  expand integer default NULL,
-  version_control integer default NULL,
-  restrict_view integer default NULL,
-  hide_backup integer default NULL,
-  dbdump_path character varying(80) default NULL,
-  gzip_path character varying(80) default NULL,
-  tar_path character varying(80) default NULL,
-  unzip_path character varying(80) default NULL,
-  pod2html_path character varying(80) default NULL,
-  pdftotext_path character varying(80) default NULL,
-  wordtotext_path character varying(80) default NULL,
-  file_perm integer default NULL,
-  folder_perm integer default NULL,
-  logging integer default NULL,
-  log_file integer default NULL,
-  log_login integer default NULL,
-  log_rec_per_page integer default NULL,
-  rec_per_page integer default NULL,
-  self_reg integer default NULL,
-  self_reg_quota integer default NULL,
-  self_reg_notify integer default NULL,
-  self_reg_attachfile integer default NULL,
-  self_reg_disabled integer default NULL,
-  self_reg_noprefacces integer default NULL,
-  self_reg_maxsessions integer default NULL,
-  self_reg_group integer default NULL,
-  anon_ro integer default NULL,
-  anon_user integer default NULL,
-  file_admin_group integer default NULL,
-  forgot_pass integer default NULL,
-  collect_trash integer default NULL,
-  trash_can_location character varying(80) default NULL,
-  allow_popup integer default NULL,
-  allow_custpopup integer default NULL,
-  status_bar_location integer default NULL,
-  remember_me integer default NULL,
-  cookie_timeout integer default NULL,
-  use_smtp integer default NULL,
-  use_smtp_auth integer default NULL,
-  smtp_passwd character varying(40) default NULL,
-  search_bar integer default NULL,
-  bulk_buttons integer default NULL,
-  action_buttons integer default NULL,
-  folder_tools integer default NULL,
-pref_bar integer default NULL,
-  smtp_auth_login character varying(50) default NULL,
-  expand_disp_status integer default NULL,
-  expand_disp_doc_num integer default NULL,
-  expand_disp_doc_type integer default NULL,
-  expand_disp_title integer default NULL,
-  expand_disp_version integer default NULL,
-  expand_disp_file integer default NULL,
-  expand_disp_size integer default NULL,
-  expand_disp_posted integer default NULL,
-  expand_disp_updated integer default NULL,
-  expand_disp_modified integer default NULL,
-  expand_disp_action integer default NULL,
-  expand_disp_held integer default NULL,
-  collapse_disp_status integer default NULL,
-  collapse_disp_doc_num integer default NULL,
-  collapse_disp_doc_type integer default NULL,
-  collapse_disp_title integer default NULL,
-  collapse_disp_version integer default NULL,
-  collapse_disp_file integer default NULL,
-  collapse_disp_size integer default NULL,
-  collapse_disp_posted integer default NULL,
-  collapse_disp_updated integer default NULL,
-  collapse_disp_modified integer default NULL,
-  collapse_disp_action integer default NULL,
-  collapse_disp_held integer default NULL,
-  expand_search_disp_score integer default NULL,
-  expand_search_disp_folder_path integer default NULL,
-  expand_search_disp_doc_type integer default NULL,
-  expand_search_disp_file integer default NULL,
-  expand_search_disp_size integer default NULL,
-  expand_search_disp_posted integer default NULL,
-  expand_search_disp_updated integer default NULL,
-  expand_search_disp_modified integer default NULL,
-  expand_search_disp_action integer default NULL,
-  collapse_search_disp_score integer default NULL,
-  colps_search_disp_fld_path integer default NULL,
-  collapse_search_disp_doc_type integer default NULL,
-  collapse_search_disp_file integer default NULL,
-  collapse_search_disp_size integer default NULL,
-  collapse_search_disp_updated integer default NULL,
-  collapse_search_disp_modified integer default NULL,
-  collapse_search_disp_action integer default NULL,
-  hide_folder_doc_count integer default NULL,
-  old_action_icons integer default NULL,
-  search_result_folders integer default NULL,
-  restore_file_prefix character varying(50) default NULL,
-  major_revision integer default NULL,
-  minor_revision integer default NULL,
-  doc_id_prefix character varying(10) default NULL,
-  doc_id_num_digits integer default NULL,
-  view_doc_in_new_window integer default NULL,
-  admin_login_to_browse_page integer default NULL,
-  save_keywords_to_db integer default NULL,
-  self_reg_homedir integer default NULL,
-  self_reg_firstdir integer default NULL,
-  virus_path character varying(80) default NULL,
-  peer_review integer default NULL,
-  peer_opt integer default NULL,
-  folder_size integer default NULL,
-  download_folder_zip integer default NULL,
-  display_password_override integer default NULL,
-  thumb_disp_status integer default NULL,
-  thumb_disp_doc_num integer default NULL,
-  thumb_disp_image_info integer default NULL,
-  thumb_disp_version integer default NULL,
-  thumb_disp_size integer default NULL,
-  thumb_disp_posted integer default NULL,
-  thumb_disp_updated integer default NULL,
-  thumb_disp_modified integer default NULL,
-  thumb_disp_action integer default NULL,
-  thumb_disp_held integer default NULL,
-  thumbnails_tool_path character varying(255) default NULL,
-  thumbnails_video_tool_path character varying(255) default NULL,
-  thumbnails_video_tool_opt character varying(255) default NULL,
-  thumbnails integer default NULL,
-  thumbnails_small_width integer default NULL,
-  thumbnails_med_width integer default NULL,
-  thumbnails_large_width integer default NULL,
-  thumbnail_view_columns integer default NULL,
-  rtftotext_path character varying(250) default NULL,
-  min_pass_length integer default NULL,
-  min_username_length integer default NULL,
-  min_pass_numeric integer default NULL,
-  min_pass_special integer default NULL,
-  enable_lock_account integer default NULL,
-  lock_account_bad_password integer default NULL,
-  track_user_passwords integer default NULL,
-  change_password_every integer default NULL,
-  folderdescreq integer default NULL,
-  show_user_info integer default NULL,
-  filedescreq integer default NULL,
-  collapse_search_disp_doc_num integer default NULL,
-  expand_search_disp_doc_num integer default NULL,
-  colps_search_disp_doc_fields integer default NULL,
-  expand_search_disp_doc_fields integer default NULL,
-  collapse_disp_doc_fields integer default NULL,
-  expand_disp_doc_fields integer default NULL,
-  self_create_homedir  integer default NULL,
-  self_captcha  integer default NULL,
-  info_panel_wide integer default NULL,
-  track_favorites  integer default NULL,
-    primary key (id)
+    id serial NOT NULL,
+    email_from character varying(80),
+    email_fromname character varying(80),
+    email_replyto character varying(80),
+    email_server character varying(80),
+    email_subject character varying(60),
+    lookathd character varying(15),
+    lookathddel integer,
+    def_file_security integer,
+    def_file_group_owner integer,
+    def_file_owner integer,
+    def_file_title character varying(40),
+    def_file_meta character varying(40),
+    def_fold_security integer,
+    def_fold_group_owner integer,
+    def_fold_owner integer,
+    max_filesize integer,
+    tmpdir character varying(255),
+    timeout integer,
+    expand integer,
+    version_control integer,
+    restrict_view integer,
+    hide_backup integer,
+    dbdump_path character varying(80),
+    gzip_path character varying(80),
+    tar_path character varying(80),
+    unzip_path character varying(80),
+    pod2html_path character varying(80),
+    pdftotext_path character varying(80),
+    wordtotext_path character varying(80),
+    file_perm integer,
+    folder_perm integer,
+    logging integer,
+    log_file integer,
+    log_login integer,
+    log_rec_per_page integer,
+    rec_per_page integer,
+    self_reg integer,
+    self_reg_quota integer,
+    self_reg_notify integer,
+    self_reg_attachfile integer,
+    self_reg_disabled integer,
+    self_reg_noprefacces integer,
+    self_reg_maxsessions integer,
+    self_reg_group integer,
+    anon_ro integer,
+    anon_user integer,
+    file_admin_group integer,
+    forgot_pass integer,
+    collect_trash integer,
+    trash_can_location character varying(80),
+    allow_popup integer,
+    allow_custpopup integer,
+    status_bar_location integer,
+    remember_me integer,
+    cookie_timeout integer,
+    use_smtp integer,
+    use_smtp_auth integer,
+    smtp_passwd character varying(40),
+    search_bar integer,
+    bulk_buttons integer,
+    action_buttons integer,
+    folder_tools integer,
+    pref_bar integer,
+    smtp_auth_login character varying(50),
+    expand_disp_status integer,
+    expand_disp_doc_num integer,
+    expand_disp_doc_type integer,
+    expand_disp_title integer,
+    expand_disp_version integer,
+    expand_disp_file integer,
+    expand_disp_size integer,
+    expand_disp_posted integer,
+    expand_disp_modified integer,
+    expand_disp_action integer,
+    expand_disp_held integer,
+    collapse_disp_status integer,
+    collapse_disp_doc_num integer,
+    collapse_disp_doc_type integer,
+    collapse_disp_title integer,
+    collapse_disp_version integer,
+    collapse_disp_file integer,
+    collapse_disp_size integer,
+    collapse_disp_posted integer,
+    collapse_disp_modified integer,
+    collapse_disp_action integer,
+    collapse_disp_held integer,
+    expand_search_disp_score integer,
+    expand_search_disp_folder_path integer,
+    expand_search_disp_doc_type integer,
+    expand_search_disp_file integer,
+    expand_search_disp_size integer,
+    expand_search_disp_posted integer,
+    expand_search_disp_modified integer,
+    expand_search_disp_action integer,
+    collapse_search_disp_score integer,
+    colps_search_disp_fld_path integer,
+    collapse_search_disp_doc_type integer,
+    collapse_search_disp_file integer,
+    collapse_search_disp_size integer,
+    collapse_search_disp_posted integer,
+    collapse_search_disp_modified integer,
+    collapse_search_disp_action integer,
+    hide_folder_doc_count integer,
+    old_action_icons integer,
+    search_result_folders integer,
+    restore_file_prefix character varying(50),
+    major_revision integer,
+    minor_revision integer,
+    doc_id_prefix character varying(10),
+    doc_id_num_digits integer,
+    view_doc_in_new_window integer,
+    admin_login_to_browse_page integer,
+    save_keywords_to_db integer,
+    self_reg_homedir integer,
+    self_reg_firstdir integer,
+    virus_path character varying(80),
+    peer_review integer,
+    peer_opt integer,
+    folder_size integer,
+    download_folder_zip integer,
+    display_password_override integer,
+    thumb_disp_status integer,
+    thumb_disp_doc_num integer,
+    thumb_disp_image_info integer,
+    thumb_disp_version integer,
+    thumb_disp_size integer,
+    thumb_disp_posted integer,
+    thumb_disp_modified integer,
+    thumb_disp_action integer,
+    thumb_disp_held integer,
+    thumbnails_tool_path character varying(255),
+    thumbnails_video_tool_path character varying(255),
+    thumbnails_video_tool_opt character varying(255),
+    thumbnails integer,
+    thumbnails_small_width integer,
+    thumbnails_med_width integer,
+    thumbnails_large_width integer,
+    thumbnail_view_columns integer,
+    rtftotext_path character varying(250),
+    min_pass_length integer,
+    min_username_length integer,
+    min_pass_numeric integer,
+    min_pass_special integer,
+    enable_lock_account integer,
+    lock_account_bad_password integer,
+    track_user_passwords integer,
+    change_password_every integer,
+    folderdescreq integer,
+    show_user_info integer,
+    filedescreq integer,
+    collapse_search_disp_doc_num integer,
+    expand_search_disp_doc_num integer,
+    colps_search_disp_doc_fields integer,
+    expand_search_disp_doc_fields integer,
+    collapse_disp_doc_fields integer,
+    expand_disp_doc_fields integer,
+    self_create_homedir integer,
+    self_captcha integer,
+    info_panel_wide integer,
+    track_favorites integer,
+    expand_disp_updated integer,
+    collapse_disp_updated integer,
+    expand_search_disp_updated integer,
+    collapse_search_disp_updated integer,
+    thumb_disp_updated integer
 );
 
-INSERT INTO prefs VALUES (1,'owl@yourdomain.com','OWL','owl@yourdomain.com','localhost','[OWL] : AUTOMATED MAIL','false',1,0,0,1,'<font color=red>No Info</font>','not in',0,0,1,151200000,'/tmp',9000,1,1,0,1,'/usr/bin/mysqldump','/usr/bin/gzip','//bin/tar','/usr/bin/unzip','','/usr/bin/pdftotext','/usr/local/bin/antiword',0,0,0,1,1,25,0,0,0,0,0,0,0,0,1,0,2,2,0,0,'',1,1,1,0,30,0,0,'',1,1,1,1,1,'',1,0,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,0,1,'',1,0,'ABC',3,0,1,1,1,1,'',1,1,1,1,0,1,1,1,1,1,1,1,1,1,'/usr/bin/convert','/usr/local/bin/mplayer',' -vo png -ss 0:05 -frames 2 -nosound -really-quiet',1,25,50,100,4,'/usr/local/bin/unrtf',8,2,0,0,0,4,10,100,0,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0,0,0);
+
+INSERT INTO prefs VALUES (1,'owl@yourdomain.com','OWL','owl@yourdomain.com','localhost','[OWL] : AUTOMATED MAIL','false',1,0,0,1,'<font color=red>No Info</font>','not in',0,0,1,151200000,'/tmp',9000,1,1,0,1,'/usr/bin/mysqldump','/usr/bin/gzip','/bin/tar','/usr/bin/unzip','','/usr/bin/pdftotext','/usr/local/bin/antiword',0,0,0,1,1,25,0,0,0,0,0,0,0,0,1,0,2,2,0,0,'',1,1,1,0,30,0,0,'',1,1,1,1,1,'',1,0,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,0,1,0,1,0,'ABC-',3,0,1,1,1,1,'',1,1,1,1,0,1,1,1,1,1,1,1,1,1,'/usr/bin/convert','/usr/local/bin/mplayer',' -vo png -ss 0:05 -frames 2 -nosound -really-quiet',1,25,50,100,4,'/usr/local/bin/unrtf',8,2,0,0,0,4,10,90,0,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0,0,0);
 
 
 CREATE TABLE monitored_file (
@@ -547,7 +548,7 @@ CREATE TABLE docfields (
         field_name character varying(80) not null,
         field_position integer not null,
         field_type character varying(80) not null,
-        field_values character varying(80) not null,
+        field_values text not null,
         field_size integer not null,
         searchable integer not null,
         show_desc integer not null,
@@ -560,7 +561,7 @@ CREATE TABLE docfieldvalues (
         id serial,
         file_id integer not null ,
         field_name character varying(80) not null,
-        field_value character varying(80) not null,
+        field_value text not null,
         primary key (id)
 );
                                                                                                                                                                      
