@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2003 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: admin_dbmodify.php,v 1.26 2006/12/03 13:01:27 b0zz Exp $
+ * $Id: admin_dbmodify.php,v 1.28 2007/08/20 20:00:43 b0zz Exp $
  */
 
 ob_start();
@@ -162,7 +162,7 @@ if ($action == "user")
    {
       if ($edit_password == $edit_confpassword)
       {
-         $pass = md5($edit_password);
+         $pass = md5(stripslashes($edit_password));
       }
       else
       {
@@ -179,6 +179,7 @@ if ($action == "user")
 
    $sql->query("UPDATE $default->owl_users_table SET groupid='$groupid',username='$edit_loginname',name='$name',password='$pass',quota_current = '$quota_current', quota_max='$quota', email='$email',notify='$notify',attachfile='$attachfile',disabled='$disabled',noprefaccess='$noprefaccess',language='$newlanguage',maxsessions='$maxsessions',useradmin='$useradmin', newsadmin='$newsadmin', comment_notify = '$comment_notify', buttonstyle = '$newbuttons', homedir = '$homedir', firstdir = '$firstdir' , email_tool = '$email_tool' , change_paswd_at_login = '$change_paswd_at_login', expire_account = '$expire_account', user_auth='$user_auth', logintonewrec='$logintonewrec', groupadmin='$groupadmin', user_offset='$user_offset', viewreports='$viewreports', viewlogs='$viewlogs' where id = '$id'");
 
+   fbCheckForPasswdReuse($pass, $id);
    // Bozz Change BEGIN
    // Clean Up the member group table first
    $sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE userid = $id"); 
@@ -380,6 +381,9 @@ if ($action == "add")
       $sql->query("SELECT id FROM $default->owl_users_table WHERE username = '$edit_loginname'");
       $sql->next_record();
       $newuid = $sql->f("id");
+
+      fbCheckForPasswdReuse($pass, $newuid);
+
       $bPrimaryGroupMemberShip = true;
       for ($i = 0 ; $i <= $no_groups_displayed; $i++)
       {
@@ -466,7 +470,6 @@ if ($action == "add")
             printError("DEBUG: " . $owl_lang->err_email, $mail->ErrorInfo);
          }
       }
-
       owl_syslog(USER_ADMIN, $userid, 0, 0, $owl_lang->log_admin_created_user . $name ."(" .$edit_loginname . ") ", "ADMIN");
 
       header("Location: index.php?sess=$sess");
