@@ -215,6 +215,7 @@ if ( $action == "add_field" )
    $show_in_list = fIntializeCheckBox($show_in_list);
 
    $add = new Owl_DB;
+   $sql = new Owl_DB;
    //modified by maurizio (madal2005) jan 2006
    $add->query("INSERT INTO $default->owl_docfields_table  (doc_type_id, field_name, field_position, field_type, field_values, field_size, searchable, show_desc,required, show_in_list) values  ('$doctype', '$field_name', '$field_position', '$field_type', '$field_values', '$field_size', '$searchable','$show_desc', '$required', '$show_in_list')");
   //end modified by  madal2005
@@ -236,6 +237,12 @@ if ( $action == "add_field" )
    }
    $dir->close();
 
+   $sql->query("SELECT id FROM $default->owl_files_table  WHERE doctype = '$doctype'");
+   while ($sql->next_record())
+   {
+      $add->query("INSERT INTO $default->owl_docfieldvalues_table (file_id, field_name) values  ('" . $sql->f("id") ."', '$field_name')");
+   }
+
    $action = "";
 }
 
