@@ -9,7 +9,7 @@
  * Author: Steve Bourgeois <owl@bozzit.com>
  * Project Founder: Chris Vincent <cvincent@project802.net>
  * 
- * $Id: index.php,v 1.35 2006/10/25 13:32:57 b0zz Exp $
+ * $Id: index.php,v 1.36 2007/05/01 13:16:09 b0zz Exp $
  */
 
 ob_start();
@@ -410,7 +410,7 @@ function printusers()
          print("</td>\n");
          print("</tr>\n");
          print("</td></tr>");
-         if ($default->auth == 0)
+         if ($sql->f("user_auth") == 0)
          {
             print("<tr>\n");
             print("<td class=\"form1\">$owl_lang->password</td>\n");
