@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: log.php,v 1.11 2007/01/05 15:22:07 b0zz Exp $
+ * $Id: log.php,v 1.12 2007/08/24 10:55:20 b0zz Exp $
  */
 
 global $default, $whereclause;
@@ -19,10 +19,10 @@ require_once($default->owl_fs_root . "/lib/Net_CheckIP/CheckIP.php");
 require_once($default->owl_fs_root . "/lib/disp.lib.php");
 require_once($default->owl_fs_root . "/lib/owl.lib.php");
 
-if (!fIsAdmin())
-{
-   die("$owl_lang->err_unauthorized");
-}
+//if (!fIsAdmin())
+//{
+   //die("$owl_lang->err_unauthorized");
+//}
 
 
 if (!isset($nextrecord)) $nextrecord = 0;
@@ -366,7 +366,10 @@ if ($default->show_prefs == 1 or $default->show_prefs == 3)
 fPrintButtonSpace(12, 1);
 print("<br />\n");
 
-fPrintAdminPanel("viewlog");
+if (fIsAdmin(true))
+{
+  fPrintAdminPanel("viewlog");
+}
 
 print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\"><tr><td align=\"left\" valign=\"top\">\n");
 print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">");
