@@ -12,8 +12,8 @@
  */
                                                                                                                                                                     
 global $default;
-                                                                                                                                                                    
-require_once(dirname(dirname(__FILE__)) . "../config/owl.php");
+
+require_once(dirname(dirname(__FILE__)) . "/config/owl.php");
 require_once($default->owl_fs_root . "/lib/disp.lib.php");
 require_once($default->owl_fs_root . "/lib/owl.lib.php");
 require_once($default->owl_fs_root . "/lib/security.lib.php");
@@ -23,7 +23,10 @@ ob_end_clean();
 
 if (!fIsAdmin(true)) die("$owl_lang->err_unauthorized");
 
-fInsertUnzipedFiles($default->owl_FileDir . "/" . fid_to_name(1) , 1, $default->owl_def_fold_security, $default->owl_def_file_security, "", $default->owl_def_file_group_owner, $default->owl_def_file_owner, $default->owl_def_file_meta, "", 1, 0, 1);
+global $index_file;
+$index_file = "1";
+
+fInsertUnzipedFiles($default->owl_FileDir . "/" . fid_to_name(1) , 1, $default->owl_def_fold_security, $default->owl_def_file_security, "", $default->owl_def_file_group_owner, $default->owl_def_file_owner, $default->owl_def_file_meta, "", 1, 0, 1, $default->use_fs_false_remove_files_on_load);
 
 header("Location: " . "index.php?sess=$sess");
 ?>
