@@ -62,7 +62,7 @@ if ($action == "email_selected")
          if ($default->use_smtp_auth)
          {
             $mail->SMTPAuth = "true"; // turn on SMTP authentication
-            $mail->Username = "$default->smtp_auth_login "; // SMTP username
+            $mail->Username = "$default->smtp_auth_login"; // SMTP username
             $mail->Password = "$default->smtp_passwd"; // SMTP password
          }
       }
@@ -104,6 +104,11 @@ if ($action == "email_selected")
 // 
 if ($action == "$owl_lang->del_selected")
 {
+   foreach($fbatch as $sDeleteThis)
+   {
+      myDelete($default->trash_can_location . "/" . $default->owl_current_db . "/" . $sDeleteThis);
+      owl_syslog(TRASH_CAN, $userid, 0, 0, $owl_lang->log_admin_trash_delfile . $default->trash_can_location . "/" . $default->owl_current_db . "/" . $sDeleteThis, "ADMIN");
+   } 
    foreach($batch as $sDeleteThis)
    {
       myDelete($default->trash_can_location . "/" . $default->owl_current_db . "/" . $sDeleteThis);
@@ -276,14 +281,14 @@ if ($Dir = opendir($default->trash_can_location . "/" . $default->owl_current_db
          }
          print("<tr>\n");
          print("<td class=\"$sTrClass\">");
-         print("<input type=\"checkbox\" name=\"batch[]\" value=\"" . $sRecyclePath . "/" . $file . "\"></input>");
-         print("<a href=\"recycle.php?folder=" . $sRecyclePath . "/" . urlencode($file) . "&amp;sess=" . $sess . "&amp;action=del_folder\" onclick='return confirm(\"$owl_lang->reallydelete ?\");'><img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_misc/admin_del_folder.gif\" alt=\"$owl_lang->alt_del_this_folder $file\" title=\"$owl_lang->alt_del_this_folder $file\" border=\"0\"></img></a>");
+         print("<input type=\"checkbox\" name=\"fbatch[]\" value=\"" . $sRecyclePath . "/" . $file . "\"></input>");
+         print("<a href=\"recycle.php?folder=" . urlencode($sRecyclePath) . "/" . urlencode($file) . "&amp;sess=" . $sess . "&amp;action=del_folder\" onclick='return confirm(\"$owl_lang->reallydelete ?\");'><img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_misc/admin_del_folder.gif\" alt=\"$owl_lang->alt_del_this_folder $file\" title=\"$owl_lang->alt_del_this_folder $file\" border=\"0\"></img></a>");
          print("</td>\n");
          print("<td class=\"$sTrClass\">");
          print("<img src=\"$default->owl_graphics_url/$default->sButtonStyle/icon_filetype/folder_closed.gif\" border=\"0\" alt=\"\"></img>");
          print("</td>\n");
          print("<td class=\"$sTrClass\">");
-         print("<a class=\"$sLfList\" href=\"recycle.php?folder=" . $sRecyclePath . "/" . $file . "&amp;sess=" . $sess . "\">" . $file . "</a>");
+         print("<a class=\"$sLfList\" href=\"recycle.php?folder=" . urlencode($sRecyclePath) . "/" . urlencode($file) . "&amp;sess=" . $sess . "\">" . $file . "</a>");
          print("</td>\n");
          print("</tr>\n");
       } 
