@@ -16,7 +16,7 @@
 //
 // 
 
-$database_instance = "intranet";
+$database_instance = "test";
 $table_prefix = "";
 
 //$dblink = mysql_connect("server.hosting.your.database","username","password") or die ("could not connect");
@@ -141,7 +141,7 @@ $result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not
 
 
 print("<h3>Creating table advanced_acl....</h3>");
-$select = "CREATE TABLE " . $table_prefix ."CREATE TABLE advanced_acl (
+$select = "CREATE TABLE " . $table_prefix ."advanced_acl (
   group_id int(4) default NULL,
   user_id int(4) default NULL,
   file_id int(4) default NULL,
@@ -1089,12 +1089,10 @@ $select = "CREATE TABLE " . $table_prefix ."prefs (
   expand_search_disp_updated int(4) default NULL,
   collapse_search_disp_updated int(4) default NULL,
   thumb_disp_updated int(4) default NULL,
-  info_panel_wide int(4) default NULL,
-  track_favorites  int(4) default NULL,
   PRIMARY KEY  (id)
 ) TYPE=MyISAM;";
 
-$result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not CREATE TABLE prefs");
+$result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not CREATE TABLE prefs: " . mysql_error());
 
 
 // --
@@ -1126,8 +1124,9 @@ $select = "CREATE TABLE " . $table_prefix ."trackoldpasswd (
   id int(4) NOT NULL auto_increment,
   userid int(4) NOT NULL default '0',
   password varchar(50) NOT NULL default '',
+  KEY oldpassid (id)
 ) TYPE=MyISAM;";
-$result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not CREATE TABLE trackoldpasswd");
+$result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not CREATE TABLE trackoldpasswd:" . mysql_error());
 
 // --
 // -- Table structure for table 'users'
@@ -1178,10 +1177,11 @@ $result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not
 // -- Data for table 'users'
 // --
 
-$select = "INSERT INTO " . $table_prefix ."users VALUES (1,'0','admin','Administrator','21232f297a57a5a743894a0e4a801fc3',0,230648,'bozz',0,0,0,0,'English',0,'2005-11-14 06:18:50','2005-11-15 18:56:06',8,0,1,'rsdx_blue1',1,1,1,0,0,'2005-04-10 22:28:40','','',0,0,'',0);";
+
+$select = "INSERT INTO " . $table_prefix ."users VALUES (1,'0','admin','Administrator','21232f297a57a5a743894a0e4a801fc3',0,230648,'',0,0,0,0,'English',0,'2005-11-14 06:18:50','2005-11-15 18:56:06',8,0,1,'rsdx_blue1',1,1,1,0,0,'2005-04-10 22:28:40','','',0,0,'',0, 0, 0);";
 $result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not INSERT 'Administrator' in TABLE users");
 
-$select = "INSERT INTO " . $table_prefix ."users VALUES (2,'1','guest','Anonymous','823f67f159b22b4c9a6a96999d1dea57',0,0,'',0,0,0,1,'English',19,'2004-11-10 05:02:42','2005-10-23 08:22:16',0,0,0,'rsdx_blue1',1,1,0,0,0,'2005-10-23 08:22:16','','0',0,0,'',0);";
+$select = "INSERT INTO " . $table_prefix ."users VALUES (2,'1','guest','Anonymous','823f67f159b22b4c9a6a96999d1dea57',0,0,'',0,0,0,1,'English',19,'2004-11-10 05:02:42','2005-10-23 08:22:16',0,0,0,'rsdx_blue1',1,1,0,0,0,'2005-10-23 08:22:16','','0',0,0,'',0, 0, 0);";
 $result = mysql_db_query($database_instance,$select,$dblink) or die ("Could not INSERT 'Anonymous' in TABLE users");
 
 // --
