@@ -488,8 +488,8 @@ fPrintVaroriteLink();
 
 if (check_auth($parent, "folder_create", $userid, false, false) == 1 or  check_auth($parent, "folder_view", $userid, false, false) == 1  && !$is_backup_folder)
 {
-   if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
-   {
+   //if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
+   //{
       if ($default->show_bulk > 0 or (fIsAdmin() and $default->show_bulk == 0 ))
       {     
          if (check_auth($parent, "folder_view", $userid, false, false) == 1)
@@ -504,7 +504,7 @@ if (check_auth($parent, "folder_create", $userid, false, false) == 1 or  check_a
             fPrintActionButtons();
          //}
       }
-   }
+   //}
 }
 
 if ($default->show_folder_tools == 1 or $default->show_folder_tools == 3)
@@ -531,8 +531,8 @@ if ($default->show_folder_tools == 2 or $default->show_folder_tools == 3)
 if (check_auth($parent, "folder_create", $userid, false, false) == 1 or  check_auth($parent, "folder_view", $userid, false, false) == 1  && !$is_backup_folder)
 //if (check_auth($parent, "folder_modify", $userid, false, false) == 1 or  check_auth($parent, "folder_upload", $userid, false, false) == 1  && !$is_backup_folder)
 {
-   if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
-   {
+   //if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
+   //{
       if ($default->show_action == 2 or $default->show_action == 3 )
       {
          //if (check_auth($parent, "folder_create", $userid, false, false) == 1)
@@ -551,7 +551,7 @@ if (check_auth($parent, "folder_create", $userid, false, false) == 1 or  check_a
       {
          print("</form>");
       }
-   }
+   //}
 }
 else
 {
