@@ -266,7 +266,7 @@ $default->owl_db_id[0]           = "0";
 $default->owl_db_user[0]           = "root";
 $default->owl_db_pass[0]           = "";
 $default->owl_db_host[0]           = "localhost";
-$default->owl_db_name[0]           = "owl090";
+$default->owl_db_name[0]           = "owl095";
 $default->owl_db_display_name[0]   = "Intranet";
 $default->owl_db_ldapserver[0]     = "your.ldap.server.address";
 $default->owl_db_ldapdomain[0]     = "";
@@ -296,11 +296,11 @@ $default->peer_auto_publish[0] 	   = "false";
 
 // This is to display the version information in the footer
 
-$default->version = "Owl 0.94 20070205";
+$default->version = "Owl 0.95 20071030";
 $default->site_title = "Owl Intranet ";
 $default->phpversion = "4.3.10";
 
-$default->debug = true;
+$default->debug = false;
 
 // BEGIN Drop Down Menu Order
 
@@ -599,7 +599,7 @@ $default->version_control_backup_dir_name = "backup";
 
 $default->purge_historical_documents_days = 90;
 
-$default->default_doctype = 2;
+$default->default_doctype = 1;
 $default->default_url_doctype = 1;
 
 // On file and folder creation the ACL's of the parent are applied 
@@ -629,14 +629,14 @@ $default->pdf_custom_watermark_filepath = ""; // LEAVE Empty unless you created
 // this enables a popup window on setacl
 // that shows the users that are in the group.
 //
-$default->show_users_in_group = true;
+$default->show_users_in_group = false;
 
 // Email notification generates a valid session for users so
 // they don't have to login, to turn this feature off and
 // force the user to sign on before they get access to the file
 // set this value to false
 
-$default->generate_notify_link_session = true;
+$default->generate_notify_link_session = false;
 
 // when Owl Use FS = False the default was to delete
 // files that where imported and stored to the database
