@@ -10,7 +10,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: download.php,v 1.8 2006/12/20 15:09:39 b0zz Exp $
+ * $Id: download.php,v 1.9 2007/07/11 16:21:31 b0zz Exp $
  */
 ob_start();
 require_once(dirname(__FILE__)."/config/owl.php");
@@ -59,6 +59,11 @@ if ($action == "bulk_download")
    $fspath = $tmpDir . "/" . $filename;
    $fsize = filesize($fspath);
 
+   if (bIsMicrosoftBrowser() === true)
+   {
+      $filename = rawurlencode($filename);
+   }
+
    header("Content-Disposition: attachment; filename=\"$filename\"");
    header("Content-Location: $filename");
    header("Content-Type: $mimeType");
@@ -321,7 +326,12 @@ if ((check_auth($id, "file_download", $userid) == 1) or $bDownloadAllowed or fCh
       $sAppendVersion =  "-" . $sql->f("major_revision") . "." . $sql->f("minor_revision");
       $download_name = $firstpart . $sAppendVersion . "." . $file_extension;
    }
-   
+  
+   if (bIsMicrosoftBrowser() === true)
+   {
+      $download_name = rawurlencode($download_name); 
+   } 
+
    $mimeType = "application/octet-stream";
 
    if ($binary != 1)
