@@ -10,7 +10,7 @@
  * 
  * small change here
  * 
- * $Id: index.php,v 1.18 2007/01/05 15:22:07 b0zz Exp $
+ * $Id: index.php,v 1.20 2007/07/11 00:27:47 b0zz Exp $
  */
 
 ob_start();
@@ -147,24 +147,33 @@ function fPrintLoginPage($message = "")
       print("    	<td width=\"50%\">&nbsp;<br /></td>\n");
       print("      <td class=\"repo1\">$owl_lang->repository_list:<br /></td>\n");
       print("      <td class=\"repo2\">\n");
-      print("         <select class=\"repo3\" name=\"currentdb\" size=\"1\">\n");
+      print("         <select class=\"repo3\" name=\"currentdb\" size=\"1\" onchange=\"submit();\">\n");
 
       $i = 0;
+      if (isset($_COOKIE["owl_dbid"]))
+      {
+         $iDefaultDB = $_COOKIE["owl_dbid"];
+      }
+      elseif (isset($_POST['currentdb']) and is_numeric($_POST['currentdb']))
+      {
+         $iDefaultDB = $_POST['currentdb'];
+      }
+      elseif (isset($default->owl_current_db))
+      {
+         $iDefaultDB = $default->owl_current_db;
+      }
+      else
+      {
+         $iDefaultDB = $default->owl_default_db;
+      }
+
       foreach($default->owl_db_display_name as $database)
       {
-         print("<option value=\"$i\" "); 
+         print("<option value=\"$i\""); 
          
-         if (isset($_COOKIE["owl_dbid"]))
-         {
-            $iDefaultDB = $_COOKIE["owl_dbid"];
-         }
-         else
-         {
-            $iDefaultDB = $default->owl_default_db;
-         }
          if ( $i == $iDefaultDB)
          {
-            print("selected=\"selected\"");
+            print(" selected=\"selected\"");
          }
          print(">$database</option>\n");
          $i++;
@@ -235,7 +244,7 @@ function fPrintLoginPage($message = "")
 
    if ($default->self_reg == 1)
    {
-      print("<a class=\"link2\" href=\"register.php?myaction=register\">$owl_lang->like_register</a>&nbsp;&nbsp;");
+      print("<a class=\"link2\" href=\"register.php?myaction=register&c=$iDefaultDB\">$owl_lang->like_register</a>&nbsp;&nbsp;");
    }
 
    if ($default->self_reg == 1 and $default->forgot_pass == 1)
@@ -245,7 +254,7 @@ function fPrintLoginPage($message = "")
 
    if ($default->forgot_pass == 1)
    {
-      print("<a class=\"link2\" href=\"register.php?myaction=forgot\">$owl_lang->forgot_pass<br /></a>");
+      print("<a class=\"link2\" href=\"register.php?myaction=forgot&c=$iDefaultDB\">$owl_lang->forgot_pass<br /></a>");
    }
 
    print("</td></tr>\n");
@@ -400,7 +409,7 @@ if (($_POST[loginname]) or ($default->auth == 1 and $_POST[loginname] and $login
            if ($default->use_smtp_auth)
            {
               $mail->SMTPAuth = "true"; // turn on SMTP authentication
-              $mail->Username = "$default->smtp_auth_login "; // SMTP username
+              $mail->Username = "$default->smtp_auth_login"; // SMTP username
               $mail->Password = "$default->smtp_passwd"; // SMTP password
            }
         }
@@ -564,7 +573,7 @@ if ($sql->num_rows() == 1)
 if (($login == 1) || ($failure > 0))
 {
    include_once($default->owl_fs_root . "/lib/header.inc");
-   include_once($default->owl_fs_root . "/lib/userheader.inc");
+   //include_once($default->owl_fs_root . "/lib/userheader.inc");
 
    print("<center>\n");
    if ($failure == 1) 
@@ -591,7 +600,7 @@ if (($login == 1) || ($failure > 0))
 if ($login == "logout")
 {
    include_once($default->owl_fs_root . "/lib/header.inc");
-   include_once($default->owl_fs_root . "/lib/userheader.inc");
+   //include_once($default->owl_fs_root . "/lib/userheader.inc");
    print("<center>\n");
    if ($default->auth == 0 or $default->auth == 2)
    {
