@@ -437,7 +437,7 @@ function InsertHDFilezInDB($TheFile, $parent, $ThePath, $DBTable)
       $iGroupOwner = $default->owl_def_file_group_owner;
    }
 
-   $SQL = "INSERT INTO $DBTable (name,filename,f_size,creatorid, updatorid,parent,created,description,metadata,security,groupid,smodified,approved,linkedto, major_revision,minor_revision, url) values ('$title_name', '$TheFile', '$iFileSize', '$iCreatorID',  '$iCreatorID','$parent', '$FileInfo[2]', '$sDescription', '$sMetadata', '$iSecurity', '$iGroupOwner','$FileInfo[2]', '1', '0', '$default->major_revision', '$default->minor_revision', '0')";
+   $SQL = "INSERT INTO $DBTable (name,filename,f_size,creatorid, updatorid,parent,created,description,metadata,security,groupid,smodified,approved,linkedto, major_revision,minor_revision, url, doctype) values ('$title_name', '$TheFile', '$iFileSize', '$iCreatorID',  '$iCreatorID','$parent', '$FileInfo[2]', '$sDescription', '$sMetadata', '$iSecurity', '$iGroupOwner','$FileInfo[2]', '1', '0', '$default->major_revision', '$default->minor_revision', '0', '$default->default_doctype')";
 
    $sql->query($SQL);
 
@@ -500,6 +500,38 @@ function InsertHDFilezInDB($TheFile, $parent, $ThePath, $DBTable)
       unlink($sOwlControlFile);
    }
 
+   $sql_custom = new Owl_DB;
+
+   $sql_custom->query("SELECT * FROM $default->owl_docfields_table  WHERE doc_type_id = '$default->default_doctype'");
+   while ($sql_custom->next_record())
+   {
+       switch ($sql_custom->f("field_type"))
+       {
+          case "seperator":
+             break;
+          case "mcheckbox":
+                $aMultipleCheckBox = split("\|",  $sql_custom->f("field_values"));
+                 $i = 0;
+                 $sFieldValues = "";
+                 foreach ($aMultipleCheckBox as $sValues)
+                 {
+                    $sFieldName = $sql_custom->f("field_name") . "_".$i;
+                                                                                                                                                       
+                    if ($i > 0)
+                    {
+                       $sFieldValues .= ",";
+                    }
+                    $sFieldValues .= ${$sFieldName};
+                    $i++;
+                 }
+                 $result = $sql->query("INSERT INTO $default->owl_docfieldvalues_table (file_id, field_name, field_value) values ('$searchid', '" . $sql_custom->f("field_name") ."', '" . $sFieldValues ."');");
+              break;
+           default:
+                 $result = $sql->query("INSERT INTO $default->owl_docfieldvalues_table (file_id, field_name, field_value) values ('$searchid', '" . $sql_custom->f("field_name") ."', '" . ${$sql_custom->f("field_name")} ."');");
+              break;
+       }
+   }
+
    owl_syslog(FILE_UPLOAD, $default->owl_def_file_owner, $TheFile, $parent, $owl_lang->log_detail . $owl_lang->log_readhd_feature_add, "FILE");
   
    fSetDefaultFileAcl($searchid); 
