@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: modify.php,v 1.30 2007/02/05 18:09:53 b0zz Exp $
+ * $Id: modify.php,v 1.31 2007/10/06 17:46:10 b0zz Exp $
  */
 
 require_once(dirname(__FILE__)."/config/owl.php");
@@ -76,7 +76,7 @@ if ($action == "file_comment")
       print("<td align=\"left\" valign=\"top\">\n");
       print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
 
-      fPrintFormTextArea($owl_lang->comments . ":", "newcomment", $sCommentValue,5,80);
+      fPrintFormTextArea($owl_lang->comments . ":", "newcomment", $sCommentValue,15,80);
       print("<tr>\n");
       print("<td class=\"form1\">");
       fPrintButtonSpace(1, 1);
@@ -1048,7 +1048,7 @@ if ($action == "file_modify")
       } 
       else
       {
-         fPrintCustomFields ($sql->f("doctype"), $sql->f("id"), $sql->f("required"));
+         fPrintCustomFields ($sql->f("doctype"), $sql->f("id"));
          if ($default->file_desc_req == "1")
          {
             $sRequiredDesc = "<font color=\"red\"><b>&nbsp;*&nbsp;</b></font>";
