@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: move.php,v 1.9 2006/08/16 23:50:55 b0zz Exp $
+ * $Id: move.php,v 1.12 2007/09/14 12:24:18 b0zz Exp $
  */
 
 global $order, $sortorder, $sortname;
@@ -274,6 +274,9 @@ function showFoldersIn($fid, $folder)
          $result = $sql->query("INSERT INTO $default->owl_files_table (name,filename,f_size,creatorid,parent,created,description,metadata,security,groupid,smodified,checked_out, major_revision, minor_revision, url, doctype, updatorid, linkedto, approved) values ('" . addslashes($sql->f("name")) . "', '" . addslashes($sql->f("filename")) . "', '" . $sql->f("f_size") . "', '" . $sql->f("creatorid") . "', '$newFolder', '" . $sql->f("created") . "', '" . addslashes($sql->f("description")) . "', '" . addslashes($sql->f("metadata")) . "', '" . $sql->f("security") . "', '" . $sql->f("groupid") . "','" . $sql->f("smodified") . "','" . $sql->f("checked_out") . "','" . $sql->f("major_revision") . "','" . $sql->f("minor_revision") . "', '" . $sql->f("url") . "', '" . $sql->f("doctype") . "', '" . $sql->f("updatorid") ."' , '$id', '" . $sql->f("approved") ."')");
          $newid = $sql->insert_id($default->owl_files_table, 'id');
 
+         fSetDefaultFileAcl($newid);
+         fSetInheritedAcl($newFolder, $newid, "FILE");
+
          owl_syslog(FILE_LINKED, $userid, flid_to_filename($newid), $parent, $owl_lang->log_file_to . fid_to_name($newFolder), "FILE");
          displayBrowsePage($parent);
       }
@@ -479,12 +482,21 @@ function showFoldersIn($fid, $folder)
 
          $result = $sql->query("INSERT INTO $default->owl_files_table (name,filename,f_size,creatorid,parent,created,description,metadata,security,groupid,smodified,checked_out, major_revision, minor_revision, url, doctype, linkedto, approved) values ('" . $sql->f("name") . "', '" . $sql->f("filename") . "', '" . $sql->f("f_size") . "', '" . $sql->f("creatorid") . "', '$newFolder', '" . $sql->f("created") . "', '" . addslashes($sql->f("description")) . "', '" . $sql->f("metadata") . "', '" . $sql->f("security") . "', '" . $sql->f("groupid") . "','" . $sql->f("smodified") . "','" . $sql->f("checked_out") . "','" . $sql->f("major_revision") . "','" . $sql->f("minor_revision") . "', '" . $sql->f("url") . "', '" . $sql->f("doctype") . "', '" . $sql->f("linkedto") . "', '" . $sql->f("approved") ."')");
          $newid = $sql->insert_id($default->owl_files_table, 'id');                                                                                                                                                                                               
-         if (file_exists($default->thumbnails_location . "/" . $id . "_small.png"))
+         if (file_exists($default->thumbnails_location . "/" . $default->owl_current_db . "_" . $id . "_small.png"))
          {
             copy ($default->thumbnails_location . "/" . $default->owl_current_db . "_" . $id . "_small.png", $default->thumbnails_location . "/" . $default->owl_current_db . "_" . $newid . "_small.png");
             copy ($default->thumbnails_location . "/" . $default->owl_current_db . "_" . $id . "_med.png", $default->thumbnails_location . "/" . $default->owl_current_db . "_" . $newid . "_med.png");
             copy ($default->thumbnails_location . "/" . $default->owl_current_db . "_" . $id . "_large.png", $default->thumbnails_location . "/" . $default->owl_current_db . "_" . $newid . "_large.png");
          }
+        // INSERT Associated Custom Fields
+         $GetDoctype = new Owl_DB;
+         $PutDoctype = new Owl_DB;
+
+         $GetDoctype->query("SELECT * from $default->owl_docfieldvalues_table  where file_id ='" . $id . "'");
+         while ( $GetDoctype->next_record() )
+         {
+            $PutDoctype->query("INSERT into $default->owl_docfieldvalues_table (file_id, field_name, field_value) values ('$newid', '" . $GetDoctype->f("field_name") . "' , '" . $GetDoctype->f("field_value") . "')");
+         }
 
          if (!$default->owl_use_fs) 
          {
