@@ -8,14 +8,18 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: search.php,v 1.18 2006/03/24 21:24:47 b0zz Exp $
+ * $Id: search.php,v 1.32 2006/12/15 13:50:51 b0zz Exp $
  */
+
 require_once(dirname(__FILE__)."/config/owl.php");
 require_once($default->owl_fs_root ."/lib/disp.lib.php");
 require_once($default->owl_fs_root ."/lib/owl.lib.php");
 require_once($default->owl_fs_root ."/lib/security.lib.php");
 
 
+$sql = new Owl_DB;
+
+
 if (isset($search_id))
 {
      $sql->query("SELECT metadata FROM $default->owl_files_table where id = '$search_id'");
@@ -27,7 +31,7 @@ if (isset($search_id))
      $sql->query("SELECT field_value FROM $default->owl_docfieldvalues_table where file_id = '$search_id'");
      while($sql->next_record()) 
      {
-        $query .= $sql->f("field_value");
+        $query .= " " . $sql->f("field_value");
      }
 }
 
@@ -52,6 +56,8 @@ $dStartTime = time();
 
 $groupid = owlusergroup($userid);
 
+$iCurrentFolder = $currentfolder;
+
 $query = trim($query);
 $query = str_replace("+", "\+", $query);
 $query = str_replace("*", "\*", $query);
@@ -103,7 +109,7 @@ if (strlen(trim($query)) == 0)
    if ($default->show_search == 2 or $default->show_search == 3)
    {
       fPrintSpacer();
-      fPrintSearch(1);
+      fPrintSearch(1, $withindocs, $iCurrentFolder);
    }
    fPrintButtonSpace(12, 1);
 
@@ -116,8 +122,6 @@ if (strlen(trim($query)) == 0)
    exit;
 }
 
-$sql = new Owl_DB;
-
 // added by rsa@newtec.be (Ruben Samaey)
 // setting up a second db connection to search tables based on a still running query
 // needed for searching for matches in comments attached to files
@@ -220,7 +224,7 @@ fPrintNavBar($parent, $owl_lang->search . ":&nbsp;");
 if ($default->show_search == 1 or $default->show_search == 3)
 {
    $keywords = $query;
-   fPrintSearch();
+   fPrintSearch(0, $withindocs, $iCurrentFolder);
    fPrintSpacer();
 }  
 
@@ -248,7 +252,7 @@ while($sql->next_record())
    {
       if($keyword <> "*")
       {
-         $sFolderCreator = flid_to_creator($sql->f("creatorid"));
+         $sFolderCreator = uid_to_name($sql->f("creatorid"));
          if(eregi("$keyword", $sql->f("name")) or eregi("$keyword", $sql->f("description")) or eregi("$keyword", $sFolderCreator))
          {
             if(check_auth($id, "folder_view", $userid, false, false) == 1) 
@@ -292,6 +296,8 @@ foreach($folders as $item)
    $keywords = str_replace(', ', ' ', $keywords);
    $keywords = str_replace(',', ' ', $keywords);
    $keywords = str_replace('  ', ' ', $keywords);
+   $keywords = stripslashes($keywords);
+   $keywords = str_replace('\\\\', '\\', $keywords);
 
    #Replace asterisks with % signs for MySQL wildcards
    $keywords = str_replace("*", "%", $keywords);
@@ -304,7 +310,7 @@ foreach($folders as $item)
       if($boolean == "phrase")
       {
          #Match the entire term
-         $sql = new Owl_DB;
+         //$sql = new Owl_DB;
             $keywords = strtolower($keywords);
 
             $sql->query("SELECT * from $default->owl_wordidx where word like '%$keywords%'");
@@ -334,7 +340,7 @@ foreach($folders as $item)
          #Match any or all words
          $keywordid = '';
          $tok = strtok($keywords, " ");
-         while($tok)
+         while($tok !== false)
          {
                $sql->query("SELECT * from $default->owl_wordidx where word like '%$tok%'");
                if ($sql->num_rows() > 0)
@@ -402,7 +408,8 @@ foreach($folders as $item)
       {
          #Match any or all words
          $tok = strtok($keywords, " ");
-         while($tok)
+
+         while($tok !== false)
          {
             $glue3 = "";
             $sql_two->query("select field_name from $default->owl_docfields_table");
@@ -440,7 +447,9 @@ foreach($folders as $item)
 
    if ($withindocs == "1")
    {
-     $sql->query("SELECT distinct f_size, smodified, f.id as fid, parent, name, metadata, description, filename, checked_out, url, doctype, updatorid FROM $default->owl_files_table f left outer join $default->owl_searchidx on owlfileid=f.id where approved = '1' and parent = '$item' $sqlquery group by fid");
+     $sql->query("SELECT distinct  f.id as fid, f_size, smodified, parent, name, metadata, description, filename, checked_out, url, doctype, updatorid FROM $default->owl_files_table f left outer join $default->owl_searchidx on owlfileid=f.id where approved = '1' and parent = '$item' $sqlquery ");
+
+     //$sql->query("SELECT distinct  f.id as fid, f_size, smodified, parent, name, metadata, description, filename, checked_out, url, doctype, updatorid FROM $default->owl_files_table f left outer join $default->owl_searchidx on owlfileid=f.id where approved = '1' and parent = '$item' $sqlquery group by fid");
      //print("<br />DEBUG: SELECT distinct f_size, smodified, f.id as fid, parent, name, metadata, description, filename, checked_out, url, doctype, updatorid FROM $default->owl_files_table f left outer join $default->owl_searchidx on owlfileid=f.id where approved = '1' and parent = '$item' $sqlquery group by fid");
 
    }
@@ -451,7 +460,6 @@ foreach($folders as $item)
      //print("<br /> DEBUG: $sqlquery2");
      $sql->query($sSearchQuery);
      $sqlquery2 = "";
-     
    }
    
 
@@ -525,6 +533,7 @@ if (strlen(trim($query))>0)
 {
    //
    // break up our query string
+   $query = str_replace('\\\\','\\', stripslashes($query));
    $query = explode(" ", $query);
    //
    // the is the meat of the matching
@@ -629,9 +638,9 @@ print("</div>");
       $minsDiff = floor($diff/60);
       $diff -= $minsDiff*60;
       $secsDiff = $diff;
-   
+
       print("<div class=\"searchresult\">($owl_lang->elapsed_time ".$minsDiff.'m '.$secsDiff.'s)'."</div>");
-      print("<div class=\"searchresult\"> $owl_lang->search_results_for &ldquo;".htmlspecialchars(implode(" ", $query))."&rdquo;</div><br />");
+      print("<div class=\"searchresult\"> $owl_lang->search_results_for &ldquo;".htmlspecialchars(str_replace('\\\\','\\', stripslashes(implode(" ", $query))))."&rdquo;</div><br />");
    
       $max = 90;
       $hit = 1;
@@ -679,7 +688,7 @@ print("</div>");
       }
       if (($default->expand_search_disp_updated and $expand == 1) or ($default->collapse_search_disp_updated and $expand == 0))
       {
-         print("<td class=\"title1\">UPDATED BY</td>\n");
+         print("<td class=\"title1\">$owl_lang->updated_by</td>\n");
       }
       if (($default->expand_search_disp_modified and $expand == 1) or ($default->collapse_search_disp_modified and $expand == 0))
       {
@@ -704,18 +713,23 @@ print("</div>");
 
           $CountLines++;
           $PrintLines = $CountLines % 2;
-          print("<tr>\n");
-          if ($PrintLines == 0)
+ 	  if ($PrintLines == 0)
           {
-            $sTrClass = "file1";
-            $sLfList = "lfile1";
+             $sTrClass = "hover1";
+             $sLfList = "lfile1";
+             $sTrClassHilite = "mouseover1";
+             $sTrClassHiliteAlt = "mouseover3";
           }
           else
           {
-            $sTrClass = "file2";
-            $sLfList = "lfile1";
+             $sTrClass = "hover2";
+             $sLfList = "lfile1";
+             $sTrClassHilite = "mouseover2";
+             $sTrClassHiliteAlt = "mouseover3";
           }
 
+         print("\t\t\t\t<tr class=\"$sTrClassHilite\" onMouseOver=\"this.className='$sTrClassHiliteAlt'\" onMouseOut=\"this.className='$sTrClassHilite'\">");
+
          if (($default->expand_search_disp_score and $expand == 1)  or ($default->collapse_search_disp_score and $expand == 0))
          {
                   print "<td class=\"$sTrClass\">";
@@ -748,7 +762,7 @@ print("</div>");
          {
                   print "<td class=\"$sTrClass\">";
 
-                  $sPopupDescription = fCleanDomTTContent($aFolderMatchSearch[$id][description]);
+                  $sPopupDescription = fCleanDomTTContent($aFolderMatchSearch[$fkey][description]);
 
                   if ($sPopupDescription == "")
                   {
@@ -927,19 +941,24 @@ print("</div>");
                   
                   $CountLines++;
                   $PrintLines = $CountLines % 2;
-                  print("<tr>\n");
 
-         if ($PrintLines == 0)
-         {
-            $sTrClass = "file1";
-            $sLfList = "lfile1";
-         }
-         else
-         {
-            $sTrClass = "file2";
-            $sLfList = "lfile1";
-         }
-                                                                                                                                                                                                   
+                  if ($PrintLines == 0)
+                  {
+                     $sTrClass = "hover1";
+                     $sLfList = "lfile1";
+                     $sTrClassHilite = "mouseover1";
+                     $sTrClassHiliteAlt = "mouseover3";
+                  }
+                  else
+                  {
+                     $sTrClass = "hover2";
+                     $sLfList = "lfile1";
+                     $sTrClassHilite = "mouseover2";
+                     $sTrClassHiliteAlt = "mouseover3";
+                  }
+
+         print("\t\t\t\t<tr class=\"$sTrClassHilite\" onMouseOver=\"this.className='$sTrClassHiliteAlt'\" onMouseOut=\"this.className='$sTrClassHilite'\">");
+
          if (($default->expand_search_disp_score and $expand == 1) or ($default->collapse_search_disp_score and $expand == 0))
          {
                   print "<td class=\"$sTrClass\">";
@@ -1014,7 +1033,7 @@ print("</div>");
          if (($default->expand_search_disp_doc_fields and $expand == 1) or ($default->colps_search_disp_doc_fields and $expand == 0))
          {
             print("<td class=\"$sTrClass\">");
-            print("<table>\n");
+            print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n");
             fPrintCustomFields ($files[$key][doctype], $files[$key][id], 0, "visible", "readonly");
             print("</table>\n");
             print("</td>\n");
@@ -1069,34 +1088,33 @@ print("</div>");
                   }
                   print("</td>\n");
               }
-      if (($default->expand_search_disp_posted and $expand == 1) or ($default->collapse_search_disp_posted and $expand == 0))
-      {
+              if (($default->expand_search_disp_posted and $expand == 1) or ($default->collapse_search_disp_posted and $expand == 0))
+              {
                   print "<td class=\"$sTrClass\">";
                      print("<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $files[$key][id] . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\">" . fid_to_creator($files[$key][id])  ."</a>");
                      print("</td>\n");
-      }
-      if (($default->expand_search_disp_updated and $expand == 1) or ($default->collapse_search_disp_updated and $expand == 0))
-      {
+              }
+              if (($default->expand_search_disp_updated and $expand == 1) or ($default->collapse_search_disp_updated and $expand == 0))
+              {
                   print "<td class=\"$sTrClass\">";
                      print("<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $files[$key][up_id] . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\">" . uid_to_name($files[$key][up_id])  ."</a>");
                      print("</td>\n");
-      }
-      if (($default->expand_search_disp_modified and $expand == 1) or ($default->collapse_search_disp_modified and $expand == 0))
-      {
+              }
+              if (($default->expand_search_disp_modified and $expand == 1) or ($default->collapse_search_disp_modified and $expand == 0))
+              {
                   print "<td class=\"$sTrClass\">";
                      print("".date($owl_lang->localized_date_format, strtotime($files[$key][date]) + $default->time_offset));
                      print("</td>\n");
-      }
+              }
       
-      if (($default->expand_search_disp_action and $expand == 1) or ($default->collapse_search_disp_action and $expand == 0))
-      {
-                  //print "<td class='$sTrClass' id='$sLfList'>";
-                  print "<td class=\"$sTrClass\">";
-                   printFileIcons($files[$key][id],$files[$id][f],$files[$key][c],$files[$key][u],$default->owl_version_control,$ext,$files[$key][p],false);
-                     print("</td>\n");
-      }
-                  print("</tr>\n");
-                  $hit++;
+              if (($default->expand_search_disp_action and $expand == 1) or ($default->collapse_search_disp_action and $expand == 0))
+              {
+                 print "<td class=\"$sTrClass\">";
+                 printFileIcons($files[$key][id],$files[$key][f],$files[$key][c],$files[$key][u],$default->owl_version_control,$ext,$files[$key][p],false);
+                 print("</td>\n");
+              }
+              print("</tr>\n");
+              $hit++;
                }
             }
             $max--;
@@ -1105,7 +1123,7 @@ print("</div>");
    }
    else
    {
-      print "<div class=\"searchresult\">$owl_lang->search_results_for &ldquo;".htmlspecialchars(implode(" ", $query))."&rdquo;<br /><br /></div>";
+      print "<div class=\"searchresult\">$owl_lang->search_results_for &ldquo;".htmlspecialchars(str_replace('\\\\','\\', stripslashes(implode(" ", $query))))."&rdquo;<br /><br /></div>";
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\"><tr><td align=\"left\" valign=\"top\">\n");
       print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">");
       print("<tr>");
@@ -1161,7 +1179,7 @@ print("</div>");
       }
       if (($default->expand_search_disp_updated and $expand == 1) or ($default->collapse_search_disp_updated and $expand == 0))
       {
-         print("<td class=\"title1\">UPDATED BY</td>\n");
+         print("<td class=\"title1\">$owl_lang->updated_by</td>\n");
          $iColspan++;
       }
       if (($default->expand_search_disp_modified and $expand == 1) or ($default->collapse_search_disp_modified and $expand == 0))
@@ -1195,7 +1213,7 @@ print("</td>\n</tr>\n</table>\n");
 if ($default->show_search == 2 or $default->show_search == 3)
 {
    fPrintSpacer();
-   fPrintSearch(1);
+   fPrintSearch(1, $withindocs, $iCurrentFolder);
    fPrintButtonSpace(12, 12);
 }
 
