@@ -288,8 +288,6 @@ switch ($type)
      print("<form action=\"showrecords.php\" method=\"post\">\n");
      print fGetHiddenFields ($urlArgs);
      fPrintFormTextLine($owl_lang->past_number, "filter", 10);
-
-$owl_lang->past_number = "Past number of Days :";
      print("<tr>\n<td colspan=\"2\" class=\"form2\" width=\"100%\">");
      fPrintSubmitButton($owl_lang->btn_submit, $owl_lang->alt_btn_submit, "submit", "submit");
      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
@@ -308,7 +306,7 @@ $owl_lang->past_number = "Past number of Days :";
      print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
      print("<form action=\"showrecords.php\" method=\"post\">\n");
      print fGetHiddenFields ($urlArgs);
-     fPrintFormTextLine("Past number of Days :" , "filter", 10);
+     fPrintFormTextLine($owl_lang->past_number , "filter", 10);
      print("<tr>\n<td colspan=\"2\" class=\"form2\" width=\"100%\">");
      fPrintSubmitButton($owl_lang->btn_submit, $owl_lang->alt_btn_submit, "submit", "submit");
      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
@@ -401,12 +399,12 @@ print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\"><t
    {
       show_link("smodified", "sortmod", $sortmod, $order, $sess, $expand, $parent, $owl_lang->modified);
    }
-   if($default->old_action_icons or $type == "wa" or $type == "pa") 
+   if($type == "wa" or $type == "pa") 
    {
-      if (($default->expand_disp_action and $expand == 1) or ($default->collapse_disp_action and $expand == 0))
-      {
+      //if (($default->expand_disp_action and $expand == 1) or ($default->collapse_disp_action and $expand == 0))
+      //{
          print("<td class=\"title1\">$owl_lang->actions</td>\n");
-      }
+      //}
    }
    if ($default->owl_version_control == 1)
    {
@@ -1080,8 +1078,8 @@ while ($sql->next_record())
          print("<td class=\"$sTrClass\" align=\"left\">" . date($owl_lang->localized_date_format, strtotime($sql->f("smodified")) + $default->time_offset) . "</td>\n");
       }
 
-      if (($default->expand_disp_action and $expand == 1) or ($default->collapse_disp_action and $expand == 0))
-      {
+      //if (($default->expand_disp_action and $expand == 1) or ($default->collapse_disp_action and $expand == 0))
+      //{
          if ($type == "wa")
          {
             print("\t\t\t\t<td class=\"$sTrClass\" align=\"left\">");
@@ -1157,16 +1155,16 @@ while ($sql->next_record())
                print("&nbsp;<a href=\"$sUrl\"><img src=\"$default->owl_graphics_url/$default->sButtonStyle/icon_action/publish.gif\" border=\"0\" alt=\"$owl_lang->alt_publish_file\" title=\"$owl_lang->alt_publish_file\"></img></a>");
             }
             print("</td>\n");
-         }
-         else
-         {
-            if($default->old_action_icons)
-            {
-               print("\t\t\t\t<td class=\"$sTrClass\" align=\"left\">");
-               printFileIcons($sql->f("id"), $sql->f("filename"), $sql->f("checked_out"), $sql->f("url"), $default->owl_version_control, $ext, $parent, $is_backup_folder);
-               print("</td>\n");
-            }
-         }
+    //     }
+         //else
+         //{
+            //if($default->old_action_icons)
+            //{
+               //print("\t\t\t\t<td class=\"$sTrClass\" align=\"left\">");
+               //printFileIcons($sql->f("id"), $sql->f("filename"), $sql->f("checked_out"), $sql->f("url"), $default->owl_version_control, $ext, $parent, $is_backup_folder);
+               //print("</td>\n");
+            //}
+         //}
       }
    //} 
    if ($default->owl_version_control == 1)
