@@ -6,7 +6,7 @@
  * Copyright (c) 1999-2003 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: view.php,v 1.10 2006/03/06 17:39:35 b0zz Exp $
+ * $Id: view.php,v 1.20 2007/01/05 15:22:07 b0zz Exp $
  */
 
 require_once(dirname(__FILE__)."/config/owl.php");
@@ -14,7 +14,11 @@ require_once($default->owl_fs_root ."/lib/disp.lib.php");
 require_once($default->owl_fs_root ."/lib/owl.lib.php");
 require_once($default->owl_fs_root ."/lib/security.lib.php");
 require_once($default->owl_fs_root ."/phpid3v2/class.id3.php");
-require_once($default->owl_fs_root ."/lib/Mail_Mime/mimeDecode.php");
+
+if (bIsPearAvailable())
+{
+   require_once($default->owl_fs_root ."/lib/Mail_Mime/mimeDecode.php");
+}
 
  
 //$clean = ob_get_contents();  
@@ -40,7 +44,7 @@ $urlArgs['curview']     = $curview;
 
 if (!empty($fileid) and is_numeric($fileid))
 {
-   if (check_auth($id, "file_download", $userid) == 1)
+   if (check_auth($fileid, "file_download", $userid) == 1)
    {
      fGeneratePdfFile($fileid);
    }
@@ -61,64 +65,10 @@ if ($action == "pdf_show" || $action == "xls_show" || $action == "doc_show" || $
       {
          $fid = fGetPhysicalFileId($id);
          $path = $default->owl_FileDir . "/" . find_path(owlfileparent($fid)) . "/" . flid_to_filename($fid);
-         //$path = $default->owl_FileDir . "/" . find_path($parent) . "/" . flid_to_filename($id);
       } 
       else
       {
-         $uncomptmpfile = $default->owl_tmpdir . "/owltmp.$id.$sess";
-         $getfile = new Owl_DB;
-         $getfile->query("SELECT data,compressed FROM $default->owl_files_data_table WHERE id='$id'");
-         while ($getfile->next_record())
-         {
-            if ($getfile->f("compressed"))
-            {
-               $tmpfile = $default->owl_tmpdir . "/owltmp.$id.$sess.gz";
-               if ($default->debug)
-               {
-                  if (!file_exists($default->owl_tmpdir))
-                  {
-                     printError("$owl_lang->debug_tmp_not_exists");
-                  } 
-                  if (!is_writable($default->owl_tmpdir))
-                  {
-                     printError("$owl_lang->debug_tmp_not_writeable");
-                  } 
-               } 
-               if (file_exists($tmpfile)) unlink($tmpfile);
-
-               $fp = fopen($tmpfile, "wb");
-               fwrite($fp, $getfile->f("data"));
-               fclose($fp);
-
-               system($default->gzip_path . " -df $tmpfile");
-
-               $fsize = filesize($uncomptmpfile);
-               $fd = fopen($uncomptmpfile, 'rb');
-               $filedata = fread($fd, $fsize);
-               fclose($fd);
-            } 
-            else
-            {
-               $tmpfile = $default->owl_tmpdir . "/owltmp.$id.$sess";
-               if ($default->debug)
-               {
-                  if (!file_exists($default->owl_tmpdir))
-                  {
-                     printError("$owl_lang->debug_tmp_not_exists");
-                  } 
-                  if (!is_writable($default->owl_tmpdir))
-                  {
-                     printError("$owl_lang->debug_tmp_not_writeable");
-                  } 
-               } 
-               if (file_exists($tmpfile)) unlink($tmpfile);
-
-               $fp = fopen($tmpfile, "wb");
-               fwrite($fp, $getfile->f("data"));
-               fclose($fp);
-            } 
-         } 
-         $path = $uncomptmpfile;
+         $path = fGetFileFromDatbase($id);
       } 
    } 
    else
@@ -130,15 +80,28 @@ if ($action == "pdf_show" || $action == "xls_show" || $action == "doc_show" || $
 if ($action == "pdf_show" || $action == "xls_show" || $action == "doc_show" || $action == "ppt_show" || $action == "mp3_play" || $action == "inline")
 {
 
+   $sFileName = flid_to_filename($id);
+
+   if ($action == "pdf_show")
+   {
+      $fspath = fCreateWaterMark($id);
+   }
+
+   if (! $fspath === false)
+   {
+      $path = $fspath;
+   }
+
    $mimetyp = fGetMimeType(flid_to_filename($id));
 
    $len = filesize($path);
    ob_clean();
    header("Content-type: $mimetyp");
    header("Content-Length: $len");
-   header("Content-Disposition: inline; filename=" . flid_to_filename($id));
+   header("Content-Disposition: inline; filename=" . $sFileName);
    header("Content-Transfer-Encoding: binary");
    readfile($path);
+
    if (!$default->owl_use_fs)
    {
       unlink($path);
@@ -491,42 +454,11 @@ if ($action == "image_preview")
       if ($default->owl_use_fs)
       {
          $fid = fGetPhysicalFileId($id);
-         $path = find_path(owlfileparent($fid)) . "/" . flid_to_filename($fid);
+         $path = $default->owl_FileDir . "/" . find_path(owlfileparent($fid)) . "/" . flid_to_filename($fid);
       }
       else
       {
-         $path = flid_to_filename($id);
-         if (file_exists($default->owl_FileDir . "/$path")) unlink($default->owl_FileDir . "/$path");
-         $file = fopen($default->owl_FileDir . "/$path", 'wb');
-         $sql->query("SELECT data,compressed FROM $default->owl_files_data_table WHERE id='$id'");
-         while ($sql->next_record())
-         {
-            if ($sql->f("compressed"))
-            {
-               $tmpfile = $default->owl_tmpdir . "/owltmp.$id.gz";
-               $uncomptmpfile = $default->owl_tmpdir . "/owltmp.$id";
-               if (file_exists($tmpfile)) unlink($tmpfile);
-
-               $fp = fopen($tmpfile, "wb");
-               fwrite($fp, $sql->f("data"));
-               fclose($fp);
-
-               system($default->gzip_path . " -df $tmpfile");
-
-               $fsize = filesize($uncomptmpfile);
-               $fd = fopen($uncomptmpfile, 'rb');
-               $filedata = fread($fd, $fsize);
-               fclose($fd);
-
-               fwrite($file, $filedata);
-               unlink($uncomptmpfile);
-            }
-            else
-            {
-               fwrite($file, $sql->f("data"));
-            }
-            fclose($file);
-         }
+         $path = fGetFileFromDatbase($id);
       }
 
      fPrintNavBar($parent, $owl_lang->viewing . ":&nbsp;", $id);
@@ -534,7 +466,7 @@ if ($action == "image_preview")
      $fid = fGetPhysicalFileId($id);
      $sImagePreviewLocation = $default->thumbnails_location . "/" . $default->owl_current_db ."_". $fid ."_". flid_to_filename($fid);
  
-     copy($default->owl_FileDir . "/$path", $sImagePreviewLocation);
+     copy($path, $sImagePreviewLocation);
      print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
      print("<tr>\n");
      print("<td align=\"left\" valign=\"top\">\n");
@@ -737,12 +669,12 @@ if ($action == "html_show" || $action == "text_show" || $action == "note_show" |
          print("<td align=\"left\" valign=\"top\">\n");
          print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
          print('<tr>');
-         print("<td align=\"left\">");
+         print("<td align=\"left\" colspan=\"2\">");
          print('<p align="left">');
-
          if ($action == "text_show" or $action == "note_show" or $action == "html_show") 
          {
-            print("<xmp>"); 
+            //print("<table><tr><td style:white-space normal;>"); 
+            print("<table><tr><td>"); 
          }
 
          if ($action == "pod_show")
@@ -909,7 +841,9 @@ if ($action == "html_show" || $action == "text_show" || $action == "note_show" |
          else
          {
             //exit("File is HERE: $path");
-            readfile("$path"); 
+            //$fileContent = readfile("$path");
+            //echo wordwrap(file_get_contents("$path"), 80, "<br /><br />\n"); 
+            echo nl2br(htmlentities(file_get_contents("$path"))); 
          }
       } 
       else
@@ -988,7 +922,9 @@ if ($action == "html_show" || $action == "text_show" || $action == "note_show" |
       if ($action == "text_show" or $action == "note_show" or $action == "html_show") 
       {
  
-      print("</xmp>");
+      print("</td></tr></table>");
+      print("</td>");
+      print("</tr>");
       $urlArgs2 = $urlArgs;
       $urlArgs2['fileid']     = $id;
       $url = fGetURL ('view.php', $urlArgs2);
@@ -1004,7 +940,7 @@ if ($action == "html_show" || $action == "text_show" || $action == "note_show" |
       print("<img src=\"$default->owl_graphics_url/$default->sButtonStyle/icon_filetype/pdf.gif\"></img>");
       print("</td>");
       print("<td class=\"button1\">");
-      print("<a class=\"lbutton1\" href=\"$url\" title=\"$owl_lang->alt_gen_pdf\">&nbsp;" . $owl_lang->btn_gen_pdf . ";&nbsp;</a>");
+      print("<a class=\"lbutton1\" href=\"$url\" title=\"$owl_lang->alt_gen_pdf\">&nbsp;" . $owl_lang->btn_gen_pdf . "&nbsp;</a>");
       print("</td>\n");
       print("</tr>\n");
       print("</table>\n");
