@@ -227,7 +227,12 @@ while ($sql->next_record())
 
    if(($default->expand_disp_status and $expand == 1) or ($default->collapse_disp_status and $expand == 0))
    {
-      print("<td class=\"$sTrClass\">&nbsp;<br /></td>");
+      print("<td class=\"$sTrClass\">");
+      if ($default->show_bulk == 0 and ! fIsAdmin())
+      {
+         print("<input id=\"fcheckid" .  $sql->f("id") . "\" type=\"hidden\" name=\"fstyle_change\" value=\"" . $sql->f("id") . "\"></input>");
+      }
+      print ("&nbsp;<br /></td>");
    }
    if(($default->expand_disp_doc_num and $expand == 1) or ($default->collapse_disp_doc_num and $expand == 0))
    {
@@ -306,7 +311,7 @@ while ($sql->next_record())
    
       if (trim($sql->f("description")))
       {
-         print("<br /><img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_misc/transparent.gif\" border=\"0\"><a class=\"desc\">" . str_replace("\n", "<br /><img src=$default->owl_graphics_url/$default->sButtonStyle/ui_misc/transparent.gif border=\"0\"></img>", $sql->f("description")) . "</a>");
+         print("<br /><img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_misc/transparent.gif\" border=\"0\"><a class=\"desc\">" . str_replace("\n", "<br /><img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_misc/transparent.gif\" border=\"0\"></img>", $sql->f("description")) . "</a>");
       }
 
       print("</td>\n");
@@ -632,6 +637,8 @@ if ($default->owl_LookAtHD != "false")
 } 
 
 //$midf->printFooter();
+
+
 //*************************************
 // BEGIN Print Files
 //*************************************
@@ -780,6 +787,10 @@ while ($sql->next_record())
    if(($default->expand_disp_status and $expand == 1) or ($default->collapse_disp_status and $expand == 0))
    {
       print("<td class=\"$sTrClass\" align=\"left\">");
+      if ($default->show_bulk == 0 and ! fIsAdmin())
+      {
+         print("<input id=\"checkid" .  $sql->f("id") . "\" type=\"hidden\" name=\"style_change\" value=\"" . $sql->f("id") . "\"></input>");
+      }
       if ($bHasComments)
       {
          if ($bPrintNewComment)
@@ -1123,8 +1134,9 @@ while ($sql->next_record())
 // SET THE user link if requested if not thne just the name is shown
       if( $default->show_user_info == 1)
       {
-         $sLinkToUser = "<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $sql->f("creatorid") . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\"title=\"$owl_lang->last_logged " . date($owl_lang->localized_date_format , strtotime(fid_to_creator_lastlogon($sql->f("id")) + $default->time_offset))  . "\">" . uid_to_name($sql->f("creatorid")) . "</a>";
-         $sLinkToUpdator = "<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $sql->f("updatorid") . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\"title=\"$owl_lang->last_logged " . date($owl_lang->localized_date_format , strtotime(fid_to_creator_lastlogon($sql->f("id")) + $default->time_offset))  . "\">" . uid_to_name($sql->f("updatorid")) . "</a>";
+         $dDateLastLoging =  date($owl_lang->localized_date_format , strtotime(fid_to_creator_lastlogon($sql->f("id"))) + $default->time_offset);
+         $sLinkToUser = "<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $sql->f("creatorid") . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\"title=\"$owl_lang->last_logged " .  $dDateLastLoging  . "\">" . uid_to_name($sql->f("creatorid")) . "</a>";
+         $sLinkToUpdator = "<a class=\"$sLfList\" href=\"prefs.php?owluser=" . $sql->f("updatorid") . "&amp;sess=$sess&amp;expand=$expand&amp;parent=$parent&amp;order=$order&amp;sortname=$sortname\"title=\"$owl_lang->last_logged " . $dDateLastLoging  . "\">" . uid_to_name($sql->f("updatorid")) . "</a>";
       }
       else
       {
