@@ -749,7 +749,7 @@ function fRenderThumbNails($aRenderLine, $sTrClass)
       }
       if(strlen($aRenderLine['updator'][$c]) > 0 and $default->thumb_disp_updated == 1)
       {
-         print("UPDATED BY: " . $aRenderLine['updator'][$c] . "<br />"); 
+         print($owl_lang->updated_by . ": " . $aRenderLine['updator'][$c] . "<br />"); 
       }
  
       if(strlen($aRenderLine['smodified'][$c]) > 0 and $default->thumb_disp_modified == 1)
